*************************************************
* Linear and Logistic Regression
* Ph. D course , Aarhus University
* copyright: Morten Frydenberg
*            Department of Biostatistics
*
*  Most of the STATA code used at 
*                DAY 4 
*              AFTERNOON
*************************************************
cd "E:\KURSER\PostReg\Lectures\"
capture log close
log using PostReg4_2.log,replace
***********************************************
* cancer data
*********************************************** 
use oralcancer,clear
 xi:logit cancer textile i.alkcon i.genage
 xi:clogit cancer textile i.alkcon, group(genage)
 xi:clogit cancer textile i.alkcon, group(genage) or
*******************************************************
* Obsesity and sex
*******************************************************
use obese,clear
sort age
tabu obese sex,col
char sex[omit]1
xi: logit obese i.sex
xi: logit obese i.sex,or
xi: glm obese i.sex age, fam(bin) link(logit) eform
predict plogit if e(sample),mu
xi: glm obese i.sex age, fam(bin) link(log) eform
predict plog if e(sample),mu
xi: glm obese i.sex age, fam(bin) link(iden) 
predict pid if e(sample),mu
twoway ///
 (line plogit age if sex==1,clco(blue) clpa(1) clw(thick)) ///
 (line plogit age if sex==2,clco(red)  clpa(1) clw(thick)) ///
 (line plog   age if sex==1,clco(blue) clpa(dash) clw(thick)) ///
 (line plog   age if sex==2,clco(red)  clpa(dash) clw(thick)) ///
 (line pid    age if sex==1,clco(blue) clpa(dot) clw(thick)) ///
 (line pid    age if sex==2,clco(red)  clpa(dot) clw(thick)) ///
 , ytitle("prevalence") xlabel(30(5)70) saving(dum2, replace) ///
 legend(ring(0) pos(11) rows(3) ///
     label(1 "logit men" ) label(2 "logit women") ///
     label(3 "log men" )   label(4 "log women")   ///
     label(5 "ident men" ) label(6 "ident women")) 
graph export Reg4_2_plot01.wmf, replace
*******************************************************
* FEV
*******************************************************
use FEV,clear
scatter FEV id, xtit("") xlab(0(20)120) msy(O) mco(blue)
graph export Reg4_2_plot02.wmf, replace
scatter FEV personid, xtit("Person") xlab(0(5)30) msy(O) mco(blue)
graph export Reg4_2_plot03.wmf, replace
scatter FEV famcord, xtit("Family") xlab(0(2)11) msy(O) mco(blue)
graph export Reg4_2_plot04.wmf, replace

*******************************************************
* AZT
*******************************************************
use AZT,clear
twoway                    ///
(line pt1mal  time,clco(red) clwi(1) clpa(dash) )   ///
(line pt2mal  time,clco(red) clwi(1) clpa(dash) )  ///
(line pt10nor time,clco(blue) clwi(1))   ///
, ytitle("AZT") legend(pos(1) ring(0))  
graph export Reg4_2_plot05.wmf, replace

*******************************************************
* AZT
*******************************************************
scalar kA1=0.2
scalar kA2=0.03
scalar kE1=0.02
scalar kE2=0.02
scalar d=17
twoway                ///
(function y=d*kA1/(kA1-kE1)*(exp(-kE1*x)-exp(-kA1*x)) ///
, range(0 200) clwi(0.7) clco (red)) ///
(function y=d*kA2/(kA2-kE2)*(exp(-kE2*x)-exp(-kA2*x)) ///
,range(0 200) clwi(0.7) clco(blue) clpa(dash)) ///
, ytitle("Concentration") xtitle("Time")legend(off)   
graph export Reg4_2_plot06.wmf, replace

*******************************************************
log close

